from django.db import models

from account.models import Account
from products.models import Product 

class Stock(models.Model):
    STATUS_CHOICES = [
        ('Pending', 'Pending'),
        ('Approved', 'Approved'),
        ('Rejected', 'Rejected'),
    ]

    previous_value = models.IntegerField(null=True, blank=True)
    new_value = models.IntegerField(null=True, blank=True)
    variance = models.IntegerField(null=True, blank=True)
    created_on = models.DateTimeField(auto_now_add=True)
    updated_on = models.DateTimeField(auto_now=True)
    product = models.ForeignKey(Product, on_delete=models.CASCADE, null=True, blank=True)
    updated_by = models.ForeignKey(Account, on_delete=models.SET_NULL, null=True, blank=True, related_name='updated_by')
    approved_by = models.ForeignKey(Account, on_delete=models.SET_NULL, null=True, blank=True, related_name='approved_by')
    status = models.CharField(max_length=10, choices=STATUS_CHOICES, default='Pending')

    def __str__(self):
        return f'Stock ID: {self.pk}, Status: {self.status}'
